@@ -59,9 +59,10 @@ class TestParameters(DataSet):
     string = StringItem("String")
     text = TextItem("Text")
     _bg = BeginGroup("A sub group")
-    fl1 = FloatItem("Float", min=1, max=30, help="Help on float item")
-    fl2 = FloatItem("Float (col=1)", default=1., min=1, max=1,
-                  help="Help on float item").set_pos(col=1)
+    fl1 = FloatItem("Current", default=10., min=1, max=30, unit="mA",
+                    help="Threshold current")
+    fl2 = FloatItem("Float (col=1)", min=1, max=1,
+                    help="Help on float item").set_pos(col=1)
     bool1 = BoolItem("Boolean option without label")
     bool2 = BoolItem("Boolean option with label", "Label").set_pos(col=1,
                                                                    colspan=2)
@@ -86,7 +87,9 @@ class TestParameters(DataSet):
     mchoice3 = MultipleChoiceItem("MC type 3",
                                   [ str(i) for i in range(10)] ).horizontal(2)
     eg0 = EndTabGroup("group")
-    integer = IntItem("Integer", default=5, min=3, max=6).set_pos(col=2)
+    integer_slider = IntItem("Integer (with slider)",
+                             default=5, min=0, max=100, slider=True)
+    integer = IntItem("Integer", default=5, min=3, max=6).set_pos(col=1)
     
     
 if __name__ == "__main__":
