@@ -23,12 +23,12 @@ SHOW = hdf5_is_available # Show test in GUI-based test launcher
 
 import os
 from guidata.hdf5io import HDF5Reader, HDF5Writer
-from all_features import TestParameters, removefiles
+from all_features import TestParameters
 
 if __name__ == '__main__':
     # Create QApplication
     import guidata
-    guidata.qapplication()
+    _app = guidata.qapplication()
     
     if os.path.exists("test.h5"):
         os.unlink("test.h5")
@@ -42,5 +42,3 @@ if __name__ == '__main__':
         reader = HDF5Reader("test.h5")
         e.deserialize(reader)
         e.edit()
-    
-    removefiles()
\ No newline at end of file
